# Project Tinsel

- [ ] send Christmas cards @2025-12-05

## Christmas dinner

- [ ] book Christmas delivery @2025-12-23/3w
- [ ] _prep the make-ahead gravy_ @2025-12-25/1d
- [ ] **roast the potatoes** @2025-12-25/0d
- [ ] prep sprouts @2025-12-25
